==> sal-teacher-2.0.0-20160919.105641-189-sources.jar: com/baijia/tianxiao/sal/teacher/util/TeacherErrorCode.java <==
package com.baijia.tianxiao.sal.teacher.util;

/**
 * Created with IntelliJ IDEA.
 * User: Victor Weng
 * Date: 16/5/20
 * Time: 下午8:32
 * To change this template use File | Settings | File Templates.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */

import com.baijia.tianxiao.dto.UniverseErrorCode;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.enums.ErrorSide;
import com.baijia.tianxiao.enums.Platform;
import com.baijia.tianxiao.enums.Subsystem;


/**
 * @title ConsultErrorCode
 * @desc TODO
 * @author cxm
 * @date 2015年12月9日
 * @version 1.0
 */
public enum TeacherErrorCode implements UniverseErrorCode {
    MOBILE_DOUBLE(1000, "该机构已有这个手机号的老师");

    private int code;
    private String message;

    private TeacherErrorCode(int code, String msg) {
        this.code = code;
        this.message = msg;
    }

    @Override
    public ErrorSide getErrorSide() {
        return ErrorSide.SERVER;
    }

    @Override
    public Subsystem getSystem() {
        return Subsystem.TEACHER;
    }

    @Override
    public Platform getPlatform() {
        return Platform.UNKNOW;
    }

    @Override
    public int getSubsystemErrorCode() {
        return this.code;
    }

    @Override
    public String getMessage() {
        return this.message;
    }

    @Override
    public UniverseErrorCode fromCode(int code) {
        for (TeacherErrorCode errorCode : values()) {
            if (errorCode.getSubsystemErrorCode() == code) {
                return errorCode;
            }
        }
        return CommonErrorCode.UNKNOW;
    }

}

==> sal-teacher-2.34.0-20170830.111827-18-sources.jar: com/baijia/tianxiao/sal/teacher/util/TeacherErrorCode.java <==
package com.baijia.tianxiao.sal.teacher.util;

/**
 * Created with IntelliJ IDEA.
 * User: Victor Weng
 * Date: 16/5/20
 * Time: 下午8:32
 * To change this template use File | Settings | File Templates.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 * <p/>
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */

import com.baijia.tianxiao.dto.UniverseErrorCode;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.enums.ErrorSide;
import com.baijia.tianxiao.enums.Platform;
import com.baijia.tianxiao.enums.Subsystem;


/**
 * @title ConsultErrorCode
 * @desc TODO
 * @author cxm
 * @date 2015年12月9日
 * @version 1.0
 */
public enum TeacherErrorCode implements UniverseErrorCode {
    MOBILE_DOUBLE(1000, "该手机号已存在");

    private int code;
    private String message;

    private TeacherErrorCode(int code, String msg) {
        this.code = code;
        this.message = msg;
    }

    @Override
    public ErrorSide getErrorSide() {
        return ErrorSide.SERVER;
    }

    @Override
    public Subsystem getSystem() {
        return Subsystem.TEACHER;
    }

    @Override
    public Platform getPlatform() {
        return Platform.UNKNOW;
    }

    @Override
    public int getSubsystemErrorCode() {
        return this.code;
    }

    @Override
    public String getMessage() {
        return this.message;
    }

    @Override
    public UniverseErrorCode fromCode(int code) {
        for (TeacherErrorCode errorCode : values()) {
            if (errorCode.getSubsystemErrorCode() == code) {
                return errorCode;
            }
        }
        return CommonErrorCode.UNKNOW;
    }

}
